@@ -1,7 +1,6 @@
-// TODO: Treure tots els lazy_static! i fer anar alguna altra cosa
-
 use once_cell::sync::Lazy;
 
+#[allow(dead_code)]
 #[derive(serde_derive::Deserialize)]
 pub struct Environment {
     current_dir: String,
